@@ -1,16 +1,17 @@
-  /*
- * Copyright (C) 2002-2008 Jeremy Laine
- *
+/*
+ * Copyright (C) 1993-2009 Robert & Jeremy Laine
+ * See AUTHORS file for a full list of contributors.
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- *
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -53,6 +54,39 @@ CRect3d CRect3d::operator* (const real r) const
 }
 
 
+/** Return the minimum rectangle containing the current rectangle
+ *  with the given aspect ratio (width / height).
+ */
+CRect3d CRect3d::expandToRatio(const real ratio) const
+{
+    CRect3d lRect(*this);
+    const real w = width();
+    const real h = height();
+
+    if (!w || !h)
+        return lRect;
+
+   
+    const real objAspect = w / h;
+    if (objAspect > ratio)
+    {
+        const real extrah = 0.5 * h * (objAspect/ratio - 1);
+        // we are limited by the width of the window, grow logical viewport's height
+        lRect.min.y() -= extrah;
+        lRect.max.y() += extrah;
+    }
+    else
+    {
+        real extraw = 0.5 * w * (ratio/objAspect - 1);
+        // we are limited by the height of the window, grow logical viewport's width
+        lRect.min.x() -= extraw;
+        lRect.max.x() += extraw;
+    }
+
+    return lRect;
+}
+
+
 /** Return the minimum rectangle containing the current rectangle
  *  and the one given as an argument.
  *
